OiRA

Help

1. Preparación
2. Implicación
3. Identificación + Evaluación
   1. 1 Commercial manned guarding
   2. Ω Riesgos añadidos (por Ud)
      1. Ω.1 The entrance floor is often wet
   - Sin respuesta
   - Pospuesto
   - OK
   - Atención
4. Plan de acción
5. Informe
6. Grado de cumplimentación 0%

En caso de que haya identificado riesgos no incluidos en la herramienta, puede añadirlos ahora:

Importante: Para evitar duplicaciones de riesgos, le recomendamos encarecidamente que consulte antes todos los módulos previos, si no lo ha hecho aún.

Si no necesita añadir riesgos, continúe.

Anterior Continuar con el plan de acción

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More